"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _routes = require("./utils/routes");
/* eslint-disable max-len */

var routes = (0, _routes.prepareRoutes)({
  integrationConnections: '/api/node-server/manage/app/:appId/integration/connections',
  integrationConnectionsById: '/api/node-server/manage/app/:appId/integration/connections/:connectionId',
  integrationConnectionName: '/api/node-server/manage/app/:appId/integration/connections/:connectionId/name',
  integrationConnectionsUsages: '/api/node-server/manage/app/:appId/integration/connections/usages',
  integrationConnectionURL: '/api/node-server/manage/app/:appId/integration/connection/oauth/url',
  integrationConnectionToken: '/api/node-server/manage/app/:appId/integration/connection/:connectionId/token',
  integrationServiceAppConfigs: '/api/node-server/manage/app/:appId/integration/service/:serviceId/app-configs',
  elementParamDictionary: '/api/node-server/manage/app/:appId/integration/block/:serviceName/param-dictionary/:dictionaryName',
  elementParamSchema: '/api/node-server/manage/app/:appId/integration/block/:serviceName/param-schema/:schemaLoaderName',
  elementSampleResult: '/api/node-server/manage/app/:appId/integration/block/:serviceName/sample-result/:sampleResultMethodName',
  sharedElements: '/api/node-server/manage/integration/shared/elements',
  sharedProductStatus: '/api/node-server/manage/integration/shared/product/:productId/status',
  sharedProductInstall: '/api/node-server/manage/integration/shared/product/:productId/install'
});
var _default = function _default(req) {
  return {
    getAllIntegrationConnections: function getAllIntegrationConnections(appId) {
      return req.nodeAPI.get(routes.integrationConnections(appId));
    },
    getIntegrationConnectionAccessToken: function getIntegrationConnectionAccessToken(appId, connectionId) {
      return req.nodeAPI.get(routes.integrationConnectionToken(appId, connectionId));
    },
    deleteIntegrationConnectionById: function deleteIntegrationConnectionById(appId, connectionId) {
      return req.nodeAPI["delete"](routes.integrationConnectionsById(appId, connectionId));
    },
    updateIntegrationConnectionName: function updateIntegrationConnectionName(appId, connectionId, updatedName) {
      return req.nodeAPI.put(routes.integrationConnectionName(appId, connectionId), {
        updatedName: updatedName
      });
    },
    getConnectionsUsages: function getConnectionsUsages(appId) {
      return req.nodeAPI.get(routes.integrationConnectionsUsages(appId));
    },
    getConnectionURL: function getConnectionURL(_ref) {
      var appId = _ref.appId,
        serviceName = _ref.serviceName,
        serviceId = _ref.serviceId;
      return req.nodeAPI.get(routes.integrationConnectionURL(appId)).query({
        serviceName: serviceName,
        serviceId: serviceId
      });
    },
    getSharedElements: function getSharedElements() {
      return req.nodeAPI.get(routes.sharedElements());
    },
    getElementParamDictionary: function getElementParamDictionary(appId, serviceName, dictionaryName, payload) {
      return req.nodeAPI.post(routes.elementParamDictionary(appId, serviceName, dictionaryName), payload);
    },
    getElementParamSchema: function getElementParamSchema(appId, serviceName, schemaLoaderName, payload) {
      return req.nodeAPI.post(routes.elementParamSchema(appId, serviceName, schemaLoaderName), payload);
    },
    getElementSampleResult: function getElementSampleResult(appId, serviceName, schemaLoaderName, payload) {
      return req.nodeAPI.post(routes.elementSampleResult(appId, serviceName, schemaLoaderName), payload);
    },
    getSharedProductStatus: function getSharedProductStatus(productId) {
      return req.nodeAPI.get(routes.sharedProductStatus(productId));
    },
    installSharedProduct: function installSharedProduct(_ref2) {
      var productId = _ref2.productId,
        versionId = _ref2.versionId,
        configs = _ref2.configs;
      return req.nodeAPI.post(routes.sharedProductInstall(productId), {
        versionId: versionId,
        configs: configs
      });
    },
    loadSharedAppConfigs: function loadSharedAppConfigs(appId, serviceId) {
      return req.nodeAPI.get(routes.integrationServiceAppConfigs(appId, encodeURIComponent(serviceId)));
    },
    saveSharedAppConfigs: function saveSharedAppConfigs(appId, serviceId, configs) {
      return req.nodeAPI.put(routes.integrationServiceAppConfigs(appId, encodeURIComponent(serviceId)), configs);
    }
  };
};
exports["default"] = _default;