"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.marketplace = void 0;
var _routes = require("./utils/routes");
var routes = (0, _routes.prepareRoutes)({
  sections: '/console/community/marketplace/sections',
  categories: '/console/community/marketplace/categories',
  categoryProducts: '/console/community/marketplace/categories/:categoryId/products',
  products: '/console/community/marketplace/products',
  product: '/console/community/marketplace/products/:productId',
  productResources: '/console/community/marketplace/products/:productId/resources',
  productResourcesDetails: '/console/community/marketplace/products/:productId/resources/details',
  productVersions: '/console/community/marketplace/products/:productId/versions',
  productApprove: '/console/community/marketplace/products/:productId/approve',
  productReject: '/console/community/marketplace/products/:productId/reject',
  productConfigurations: '/console/community/marketplace/products/:productId/configurations',
  productPrivateDevs: '/console/community/marketplace/products/:productId/private-devs',
  submissions: '/console/community/marketplace/submissions',
  appPurchases: '/:appId/console/community/marketplace/app-purchases',
  appPurchasesProduct: '/:appId/console/community/marketplace/app-purchases/:productId',
  appPurchasesProductExists: '/:appId/console/community/marketplace/app-purchases/:productId/exists',
  appPurchasesProductPreview: '/:appId/console/community/marketplace/app-purchases/:productId/preview',
  accountPurchases: '/console/community/marketplace/account-purchases',
  accountPurchasesProduct: '/console/community/marketplace/account-purchases/:productId',
  accountPurchasesPaymentProfile: '/console/community/marketplace/account-purchases/update-payment-profile',
  accountPurchaseReactivate: '/console/community/marketplace/account-purchases/:productId/renew',
  developerPayoutHistory: '/console/community/marketplace/developer-sales/payouts',
  developerProductSales: '/console/community/marketplace/developer-sales/product-sales',
  developerGeneralSales: '/console/community/marketplace/developer-sales/general-sales',
  installDetails: '/console/community/marketplace/installs/details',
  appInstalls: '/api/app/:appId/marketplace/installs'
});
var marketplace = function marketplace(req) {
  return {
    //---- SECTIONS ==>
    getSections: function getSections() {
      return req.get(routes.sections());
    },
    //---- SECTIONS ----//
    //---- CATEGORIES ==>
    getCategories: function getCategories(query) {
      return req.get(routes.categories()).query(query);
    },
    getCategoryProducts: function getCategoryProducts(categoryId) {
      return req.get(routes.categoryProducts(categoryId));
    },
    //---- CATEGORIES ----//
    //---- PRODUCTS ==>
    getProducts: function getProducts(query) {
      return req.get(routes.products()).query(query);
    },
    //---- PRODUCTS ----//
    //---- PRODUCT ==>
    getProduct: function getProduct(productId) {
      return req.community.get(routes.product(productId));
    },
    getProductVersions: function getProductVersions(productId, query) {
      return req.community.get(routes.productVersions(productId)).query(query);
    },
    getProductResources: function getProductResources(productId, _ref) {
      var versionId = _ref.versionId,
        filePath = _ref.filePath;
      if (filePath) {
        filePath = encodeURIComponent(filePath);
      }
      return req.community.get(routes.productResources(productId)).query({
        versionId: versionId,
        filePath: filePath
      }).setEncoding(null);
    },
    getProductResourcesDetails: function getProductResourcesDetails(productId, versionId) {
      return req.community.get(routes.productResourcesDetails(productId)).query({
        versionId: versionId
      });
    },
    getProductConfigurations: function getProductConfigurations(productId, version) {
      return req.get(routes.productConfigurations(productId)).query({
        version: version
      });
    },
    getProductPrivateDevs: function getProductPrivateDevs(productId) {
      return req.community.get(routes.productPrivateDevs(productId));
    },
    updateProductPrivateDevs: function updateProductPrivateDevs(productId, privateDevs) {
      return req.community.put(routes.productPrivateDevs(productId), privateDevs);
    },
    publishProduct: function publishProduct(product) {
      return req.post(routes.products(), product);
    },
    approveProduct: function approveProduct(productId) {
      return req.put(routes.productApprove(productId));
    },
    rejectProduct: function rejectProduct(productId, reason) {
      return req.put(routes.productReject(productId), reason);
    },
    removeProduct: function removeProduct(productId, reason) {
      return req["delete"](routes.product(productId), reason);
    },
    //---- PRODUCT ----//
    //---- PURCHASES ==>
    getAppPurchases: function getAppPurchases(appId) {
      return req.get(routes.appPurchases(appId));
    },
    allocateAppProduct: function allocateAppProduct(appId, productId, options) {
      return req.post(routes.appPurchasesProduct(appId, productId), options);
    },
    isAppProductPurchased: function isAppProductPurchased(appId, productId) {
      return req.community.get(routes.appPurchasesProductExists(appId, productId));
    },
    // previewProduct(appId, productId, options) {
    //   return req.post(routes.appPurchasesProductPreview(appId, productId), options)
    // },
    //---- PURCHASES ----//
    //---- APP INSTALLS ==>
    getAppInstalls: function getAppInstalls(appId) {
      return req.get(routes.appInstalls(appId));
    },
    getInstallsDetails: function getInstallsDetails(productIds) {
      return req.community.get(routes.installDetails()).query({
        productIds: productIds
      });
    },
    //---- APP INSTALLS ----//
    //---- SUBMISSIONS ==>
    getSubmissions: function getSubmissions() {
      return req.get(routes.submissions());
    },
    getAccountPurchases: function getAccountPurchases() {
      return req.get(routes.accountPurchases());
    },
    allocateAccountProduct: function allocateAccountProduct(productId, options) {
      return req.post(routes.accountPurchasesProduct(productId), options);
    },
    updateAccountPurchasesPaymentProfile: function updateAccountPurchasesPaymentProfile(paymentProfileId) {
      return req.put(routes.accountPurchasesPaymentProfile(), {
        paymentProfileId: paymentProfileId
      });
    },
    reactivateAccountPurchase: function reactivateAccountPurchase(productId) {
      return req.post(routes.accountPurchaseReactivate(productId));
    },
    getDeveloperPayoutHistory: function getDeveloperPayoutHistory() {
      return req.get(routes.developerPayoutHistory());
    },
    getDeveloperProductSales: function getDeveloperProductSales() {
      return req.get(routes.developerProductSales());
    },
    getDeveloperGeneralSales: function getDeveloperGeneralSales(query) {
      return req.get(routes.developerGeneralSales()).query(query);
    }
  };
};
exports.marketplace = marketplace;