"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = exports.XSLT_FILE = exports.IMAGE_FILE = void 0;
var _urls = _interopRequireDefault(require("./urls"));
var IMAGE_FILE = /(\jpg|\jpeg|\png|\gif|\ico)$/;
exports.IMAGE_FILE = IMAGE_FILE;
var XSLT_FILE = /(\.xsl|\.xslt)$/;
exports.XSLT_FILE = XSLT_FILE;
var PROJECT_TEMPLATES_PATH = 'codegen/projecttemplates';
var PROMPT_FILE_NAME = 'prompt.json';
var DEFAULT_PROMPT = 'Make a selection';
var getFolders = function getFolders(folders) {
  return folders.filter(function (_ref) {
    var size = _ref.size;
    return !size;
  });
};
var _default = function _default(req) {
  return {
    loadTemplates: function loadTemplates(appId) {
      var path = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
      var result = {};
      return loadDirectory(req, appId, "".concat(PROJECT_TEMPLATES_PATH, "/").concat(path)).then(function (children) {
        result.children = getFolders(children);
        var map = children.map(function (child) {
          if (child.name === PROMPT_FILE_NAME) {
            return loadDirectory(req, appId, child.url).then(function (_ref2) {
              var prompt = _ref2.prompt;
              return result.prompt = prompt;
            });
          } else {
            result.prompt = DEFAULT_PROMPT;
          }
          if (!child.size) {
            return loadDirectory(req, appId, child.url).then(function (children) {
              var icon = children.find(function (_ref3) {
                var name = _ref3.name;
                return IMAGE_FILE.test(name);
              });
              var readme = children.find(function (_ref4) {
                var name = _ref4.name;
                return name === 'README.md';
              });
              if (icon) {
                child.icon = _urls["default"].fileView(appId, icon.url);
              }
              var chain = Promise.resolve();
              if (readme) {
                chain = chain.then(function () {
                  return loadDirectory(req, appId, readme.url);
                }).then(function (readmeContent) {
                  return child.readme = readmeContent;
                });
              }
              chain = chain.then(function () {
                var xslt = children.find(function (_ref5) {
                  var name = _ref5.name;
                  return XSLT_FILE.test(name);
                });
                if (xslt) {
                  child.xslt = xslt.url;
                  return;
                }
                child.children = children;
              });
              return chain;
            });
          }
        });
        return Promise.all(map).then(function () {
          return result;
        });
      });
    },
    generateProject: function generateProject(appId, xsl) {
      return req.post("".concat(_urls["default"].appConsole(appId), "/codegen"), {
        xsl: xsl
      });
    }
  };
};
exports["default"] = _default;
function loadDirectory(req, appId, path) {
  return req.get(_urls["default"].fileView(appId, path));
}