"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _urls = _interopRequireDefault(require("./urls"));
var SYSTEM_API_KEYS = ['ANDROID', 'IOS', 'JS', 'REST', 'WP', 'AS', 'BL'];
function normalizeAppSettings(result) {
  var _result$apiKeys;
  var systemAPIKeys = [];
  var customAPIKeys = [];
  result.apiKeysMap = {};
  result.apiKeys.forEach(function (apiKey) {
    var systemAPIKeyIndex = SYSTEM_API_KEYS.indexOf(apiKey.deviceType);
    if (systemAPIKeyIndex >= 0) {
      systemAPIKeys[systemAPIKeyIndex] = apiKey;
      result.apiKeysMap[apiKey.deviceType] = apiKey.apiKey;
    } else {
      customAPIKeys.push(apiKey);
    }
  });
  result.apiKeys = [];
  systemAPIKeys.forEach(function (apiKey) {
    if (apiKey) {
      result.apiKeys.push(apiKey);
    }
  });
  (_result$apiKeys = result.apiKeys).push.apply(_result$apiKeys, customAPIKeys);
  return result;
}
var _default = function _default(req) {
  return {
    createAndroidMobileSettings: function createAndroidMobileSettings(appId, settings) {
      return req.post(_urls["default"].mobileSettingsAndroid(appId), settings);
    },
    updateAndroidMobileSettings: function updateAndroidMobileSettings(appId, settings, id) {
      return req.put(_urls["default"].mobileSettingsAndroid(appId, id), settings);
    },
    deleteAndroidMobileSettings: function deleteAndroidMobileSettings(appId, id) {
      return req["delete"](_urls["default"].mobileSettingsAndroid(appId, id));
    },
    createAppleMobileSettings: function createAppleMobileSettings(appId, settings, deviceType) {
      return req.post("".concat(_urls["default"].mobileSettings(appId), "/").concat(deviceType), settings);
    },
    updateAppleMobileSettings: function updateAppleMobileSettings(appId, settings, id, deviceType) {
      return req.put("".concat(_urls["default"].mobileSettings(appId), "/").concat(deviceType, "/").concat(id), settings);
    },
    deleteAppleMobileCertificate: function deleteAppleMobileCertificate(appId, id, deviceType) {
      return req["delete"]("".concat(_urls["default"].mobileSettings(appId), "/").concat(deviceType, "/").concat(id));
    },
    /**
     * @deprecated
     * */
    updateDomainNames: function updateDomainNames(appId, domainNames) {
      return req.put("".concat(_urls["default"].appConsole(appId), "/domaincontrolsettings"), domainNames.split(/\s+/));
    },
    /**
     * @deprecated
     * */
    updateCustomDomain: function updateCustomDomain(appId, domainName) {
      return req.put("".concat(_urls["default"].appConsole(appId), "/dnsmapping"), domainName);
    },
    //--------------------------------//
    //-------- CUSTOM DOMAINS --------//
    getCustomDomains: function getCustomDomains(appId) {
      return req.get("".concat(_urls["default"].appConsole(appId), "/settings/custom-domain"));
    },
    createCustomDomain: function createCustomDomain(appId, domainData) {
      return req.post("".concat(_urls["default"].appConsole(appId), "/settings/custom-domain"), domainData);
    },
    assignCustomDomain: function assignCustomDomain(appId, domainData) {
      return req.post("".concat(_urls["default"].appConsole(appId), "/settings/custom-domain/assign-generated-domain"), domainData);
    },
    changeCustomDomain: function changeCustomDomain(appId, domainData) {
      return req.put("".concat(_urls["default"].appConsole(appId), "/settings/custom-domain/").concat(domainData.id), domainData);
    },
    deleteCustomDomain: function deleteCustomDomain(appId, domainId) {
      return req["delete"]("".concat(_urls["default"].appConsole(appId), "/settings/custom-domain/").concat(domainId));
    },
    //-------- CUSTOM DOMAINS --------//
    //--------------------------------//
    updateIOSCert: function updateIOSCert(appId, data) {
      return req.post("".concat(_urls["default"].appConsole(appId), "/ioscert"), data);
    },
    getDataValidators: function getDataValidators() {
      return req.get('/console/datavalidators');
    },
    getAppSettings: function getAppSettings(appId) {
      return req.get("".concat(_urls["default"].appConsole(appId), "/appsettings")).then(normalizeAppSettings);
    },
    regenerateAPIKey: function regenerateAPIKey(appId, apiKeyId) {
      return req.post("".concat(_urls["default"].appConsole(appId), "/apikey/").concat(apiKeyId, "/regenerate"));
    },
    getAPIKey: function getAPIKey(appId, apiKeyId) {
      return req.get("".concat(_urls["default"].appConsole(appId), "/apikey/").concat(apiKeyId));
    },
    createAPIKey: function createAPIKey(appId, apiKey) {
      return req.post("".concat(_urls["default"].appConsole(appId), "/apikey"), apiKey);
    },
    updateAPIKey: function updateAPIKey(appId, apiKeyId, apiKey) {
      return req.put("".concat(_urls["default"].appConsole(appId), "/apikey/").concat(apiKeyId), apiKey);
    },
    deleteAPIKey: function deleteAPIKey(appId, apiKeyId) {
      return req["delete"]("".concat(_urls["default"].appConsole(appId), "/apikey/").concat(apiKeyId));
    },
    getAppLogging: function getAppLogging(appId) {
      return req.get("".concat(_urls["default"].appConsole(appId), "/logging/config"));
    },
    setAppLogging: function setAppLogging(appId, logging) {
      console.warn('"ApiClient.settings.setAppLogging" is deprecated method, will be removed when fixed BKNDLSS-18585');
      return this.setAppLoggingConfig(appId, logging);
    },
    setAppLoggingConfig: function setAppLoggingConfig(appId, config) {
      return req.post("".concat(_urls["default"].appConsole(appId), "/logging/config"), config);
    },
    setAppLoggingIntegration: function setAppLoggingIntegration(appId, integration) {
      return req.post("".concat(_urls["default"].appConsole(appId), "/logging/integration"), integration);
    },
    clearLoggers: function clearLoggers(appId) {
      return req["delete"]("".concat(_urls["default"].appConsole(appId), "/logging/loggers"));
    },
    updateSocialParams: function updateSocialParams(appId, param) {
      return req.post("".concat(_urls["default"].appConsole(appId), "/socialparams"), param);
    },
    getLandingPageData: function getLandingPageData(appId) {
      return req.get(_urls["default"].landingPage(appId));
    },
    getLandingPageTemplates: function getLandingPageTemplates(appId) {
      return req.get("".concat(_urls["default"].landingPage(appId), "/templates"));
    },
    saveLandingPageData: function saveLandingPageData(appId, data) {
      return req.put(_urls["default"].landingPage(appId), data);
    },
    publishLandingPageData: function publishLandingPageData(appId, data) {
      return req.post("".concat(_urls["default"].landingPage(appId), "/publish"), data);
    },
    uploadLandingPageFile: function uploadLandingPageFile(appId, file, section, name) {
      return req.post("".concat(_urls["default"].landingPage(appId), "/file")).query({
        section: section,
        name: name
      }).form({
        file: file
      });
    }
  };
};
exports["default"] = _default;