"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.sqlService = void 0;
var _routes = require("./utils/routes");
var routes = (0, _routes.prepareRoutes)({
  connections: '/:appId/console/sql/connection/',
  connection: '/:appId/console/sql/connection/:connectionId',
  connectionTables: '/:appId/console/sql/connection/:connectionId/tables',
  connectionRoutines: '/:appId/console/sql/connection/:connectionId/routines',
  connectionQueries: '/:appId/console/sql/:connectionName/query',
  connectionQuery: '/:appId/console/sql/:connectionName/query/:queryId',
  connectionDynamicSelect: '/:appId/console/sql/:connectionName/select',
  connectionNamedSelect: '/:appId/console/sql/:connectionName/select/:queryName'
});
var sqlService = function sqlService(req) {
  return {
    //---- CONNECTION-CONTROLLER ----//
    getConnections: function getConnections(appId) {
      return req.sqlService.get(routes.connections(appId));
    },
    createConnection: function createConnection(appId, data) {
      return req.sqlService.post(routes.connections(appId), data);
    },
    updateConnection: function updateConnection(appId, data) {
      return req.sqlService.put(routes.connection(appId, data.id), data);
    },
    getConnectionTables: function getConnectionTables(appId, connectionId) {
      return req.sqlService.get(routes.connectionTables(appId, connectionId));
    },
    getConnectionRoutines: function getConnectionRoutines(appId, connectionId) {
      return req.sqlService.get(routes.connectionRoutines(appId, connectionId));
    },
    //---- CONNECTION-CONTROLLER ----//
    //---- QUERY-CONTROLLER ----//
    getConnectionQueries: function getConnectionQueries(appId, connectionName) {
      return req.sqlService.get(routes.connectionQueries(appId, connectionName));
    },
    createConnectionQuery: function createConnectionQuery(appId, connectionName, data) {
      return req.sqlService.post(routes.connectionQueries(appId, connectionName), data);
    },
    updateConnectionQuery: function updateConnectionQuery(appId, connectionName, queryId, data) {
      return req.sqlService.put(routes.connectionQuery(appId, connectionName, queryId), data);
    },
    //---- QUERY-CONTROLLER ----//
    //---- CONSOLE-EXECUTE-CONTROLLER ----//
    runConnectionDynamicSelect: function runConnectionDynamicSelect(appId, connectionName, data) {
      return req.sqlService.post(routes.connectionDynamicSelect(appId, connectionName), data);
    },
    runConnectionNamedSelect: function runConnectionNamedSelect(appId, connectionName, queryName, data) {
      return req.sqlService.post(routes.connectionNamedSelect(appId, connectionName, queryName), data);
    } //---- CONSOLE-EXECUTE-CONTROLLER ----//
  };
};
exports.sqlService = sqlService;