"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _routes = require("./utils/routes");
var routes = (0, _routes.prepareRoutes)({
  "export": '/:appId/console/export',
  singleStepImport: '/:appId/console/import/:type',
  multiStepImport: '/:appId/console/import/data/:step',
  firebaseUsers: '/:appId/console/import/firebase/users',
  airtableBases: '/:appId/console/airtable/bases/:baseId',
  airtableImport: '/:appId/console/airtable'
});
var _default = function _default(req) {
  return {
    getExportedData: function getExportedData(appId) {
      return req.get(routes["export"](appId));
    },
    startExport: function startExport(appId, data) {
      return req.post(routes["export"](appId), data);
    },
    startImport: function startImport(appId, data, type, query) {
      return req.post(routes.singleStepImport(appId, type), data).query(query);
    },
    importDataServiceFiles: function importDataServiceFiles(appId, data, step) {
      return req.post(routes.multiStepImport(appId, step), data);
    },
    importFirebaseUsers: function importFirebaseUsers(appId, data) {
      return req.post(routes.firebaseUsers(appId), data);
    },
    getAirtableBasesList: function getAirtableBasesList(appId, accessToken) {
      return req.get(routes.airtableBases(appId)).query({
        accessToken: accessToken
      });
    },
    getAirtableTablesList: function getAirtableTablesList(appId, accessToken, baseId) {
      return req.get(routes.airtableBases(appId, baseId)).query({
        accessToken: accessToken
      });
    },
    startAirtableImport: function startAirtableImport(appId, accessToken, baseId, tables) {
      return req.post(routes.airtableImport(appId, baseId), {
        accessToken: accessToken,
        baseId: baseId,
        tables: tables
      });
    }
  };
};
exports["default"] = _default;