"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _routes = require("./utils/routes");
var routes = (0, _routes.prepareRoutes)({
  apps: '/console/applications',
  appFromZip: '/console/applications/from-zip',
  appFromZipURL: '/console/applications/from-zip-url',
  app: '/:appId/console/application',
  appDevOptions: '/:appId/console/developer/options',
  appReset: '/:appId/console/appreset',
  appClone: '/:appId/console/cloneApp',
  appCloneProcess: '/:appId/console/cloneApp/:processId',
  appTransfer: '/:appId/console/application/transfer',
  appsInfo: '/console/apps-info',
  appInfo: '/:appId/console/app-info',
  appInfoLogo: '/:appId/console/app-info/logos',
  suggestedGeneratedDomains: '/console/applications/suggested-generated-domains'
});
var _default = function _default(req) {
  return {
    createApp: function createApp(app, query) {
      return req.post(routes.apps(), app).query(query);
    },
    createAppFromZIP: function createAppFromZIP(app) {
      return req.post(routes.appFromZip(), app);
    },
    createAppFromZipUrl: function createAppFromZipUrl(data) {
      return req.post(routes.appFromZipURL(), data);
    },
    getApps: function getApps(zone) {
      return req.get(routes.apps()).query({
        zone: zone
      });
    },
    resetApp: function resetApp(appId, resets) {
      return req.post(routes.appReset(appId), resets);
    },
    renameApp: function renameApp(appId, appName) {
      return req.put(routes.app(appId), {
        appName: appName
      });
    },
    deleteApp: function deleteApp(appId) {
      return req["delete"](routes.app(appId));
    },
    cloneApp: function cloneApp(appId, newApp) {
      return req.post(routes.appClone(appId), newApp);
    },
    generateAppZIP: function generateAppZIP(appId) {
      return req.post(routes.appTransfer(appId));
    },
    getCloningAppStatus: function getCloningAppStatus(appId, processId) {
      return req.get(routes.appCloneProcess(appId, processId));
    },
    loadAppsMenuItems: function loadAppsMenuItems() {
      return req.get('/console/applications/menu-items');
    },
    loadAppFavorites: function loadAppFavorites(appId, devId) {
      return req.get('/console/applications/app-favorites').query({
        appId: appId,
        devId: devId
      });
    },
    loadAppsInfo: function loadAppsInfo(appsIds) {
      return req.get(routes.appsInfo()).query({
        appsIds: appsIds
      });
    },
    updateAppInfo: function updateAppInfo(appId, info) {
      return req.post(routes.appInfo(appId), info);
    },
    updateAppLogo: function updateAppLogo(appId, logo) {
      return req.post(routes.appInfoLogo(appId), logo);
    },
    generateSubdomains: function generateSubdomains(zone) {
      return req.get(routes.suggestedGeneratedDomains()).query({
        zone: zone
      });
    },
    getAppDevOptions: function getAppDevOptions(appId) {
      return req.get(routes.appDevOptions(appId));
    },
    updateAppDevOptions: function updateAppDevOptions(appId, options) {
      return req.put(routes.appDevOptions(appId), options);
    }
  };
};
exports["default"] = _default;