"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _urls = require("./urls");
var _routes = require("./utils/routes");
var routes = (0, _routes.prepareRoutes)({
  setKeyExpire: '/:appId/console/hive/:hiveName/:store/:key/expire',
  setKeyExpireAt: '/:appId/console/hive/:hiveName/:store/:key/expire-at',
  keyExpirationTTL: '/:appId/console/hive/:hiveName/:store/:key/get-expiration-ttl',
  clearKeyExpiration: '/:appId/console/hive/:hiveName/:store/:key/clear-expiration',
  keySecondsSinceLastOperation: '/:appId/console/hive/:hiveName/:store/:key/seconds-since-last-operation',
  //
  addListStoreItems: '/:appId/console/hive/:hiveName/list/:key/add-last',
  removeListStoreItemByValue: '/:appId/console/hive/:hiveName/list/:key/delete-value',
  listStoreItemByIndex: '/:appId/console/hive/:hiveName/list/:key/:index',
  addSetStoreItems: '/:appId/console/hive/:hiveName/set/:key/add',
  removeSetStoreItemByValue: '/:appId/console/hive/:hiveName/set/:key/values'
});
var HiveDataTypesMap = {
  KEY_VALUE: 'key-value',
  LIST: 'list',
  MAP: 'map',
  SET: 'set',
  SORTED_SET: 'sorted-set'
};
var _default = function _default(req) {
  return {
    getHiveNames: function getHiveNames(appId) {
      return req.get((0, _urls.dataHives)(appId));
    },
    createHive: function createHive(appId, hiveName) {
      return req.post("".concat((0, _urls.dataHive)(appId, hiveName)));
    },
    renameHive: function renameHive(appId, oldName, newName) {
      return req.put((0, _urls.dataHive)(appId, oldName)).query({
        newName: newName
      });
    },
    deleteHive: function deleteHive(appId, hiveName) {
      return req["delete"]("".concat((0, _urls.dataHive)(appId, hiveName)));
    },
    loadHiveStoreKeys: function loadHiveStoreKeys(appId, hiveName, storeType, _ref) {
      var pageSize = _ref.pageSize,
        cursor = _ref.cursor;
      return req.get("".concat((0, _urls.dataHive)(appId, hiveName), "/").concat(storeType, "/keys")).query({
        pageSize: pageSize,
        cursor: cursor
      });
    },
    loadHiveStoreValues: function loadHiveStoreValues(appId, hiveName, storeType, keys) {
      if (storeType === HiveDataTypesMap.KEY_VALUE) {
        return [req.post((0, _urls.dataHiveStore)(appId, hiveName, storeType), keys)];
      }
      if (storeType === HiveDataTypesMap.SORTED_SET) {
        return keys.map(function (key) {
          return req.get("".concat((0, _urls.dataHiveStoreKey)(appId, hiveName, storeType, key), "/get-range-by-rank")).query({
            startRank: 0,
            stopRank: 99,
            withScores: true
          });
        });
      }
      return keys.map(function (key) {
        return req.get((0, _urls.dataHiveStoreKey)(appId, hiveName, storeType, key));
      });
    },
    setHiveStoreValue: function setHiveStoreValue(appId, hiveName, storeType, keyName, payload) {
      return req.put((0, _urls.dataHiveStoreKey)(appId, hiveName, storeType, keyName), payload);
    },
    addHiveStoreValue: function addHiveStoreValue(appId, hiveName, storeType, keyName, payload) {
      return req.put("".concat((0, _urls.dataHiveStoreKey)(appId, hiveName, storeType, keyName), "/add"), payload);
    },
    removeHiveStoreRecords: function removeHiveStoreRecords(appId, hiveName, storeType, keys) {
      return req["delete"]((0, _urls.dataHiveStore)(appId, hiveName, storeType), keys);
    },
    removeHiveStoreValue: function removeHiveStoreValue(appId, hiveName, storeType, keyName, values) {
      return req["delete"]("".concat((0, _urls.dataHiveStoreKey)(appId, hiveName, storeType, keyName), "/values"), values);
    },
    //---- Base Type -------------------------//
    setKeyExpiration: function setKeyExpiration(appId, hiveName, storeType, key, _ref2) {
      var ttl = _ref2.ttl,
        unixTime = _ref2.unixTime;
      if (ttl !== undefined) {
        return req.put(routes.setKeyExpire(appId, hiveName, storeType, key)).query({
          ttl: ttl
        });
      }
      return req.put(routes.setKeyExpireAt(appId, hiveName, storeType, key)).query({
        unixTime: unixTime
      });
    },
    getKeyExpirationTTL: function getKeyExpirationTTL(appId, hiveName, storeType, key) {
      return req.get(routes.keyExpirationTTL(appId, hiveName, storeType, key));
    },
    clearKeyExpiration: function clearKeyExpiration(appId, hiveName, storeType, key) {
      return req.put(routes.clearKeyExpiration(appId, hiveName, storeType, key));
    },
    getKeySecondsSinceLastOperation: function getKeySecondsSinceLastOperation(appId, hiveName, storeType, key) {
      return req.get(routes.keySecondsSinceLastOperation(appId, hiveName, storeType, key));
    },
    //---- Base Type -------------------------//
    //---- LIST Type -------------------------//
    addHiveListStoreItems: function addHiveListStoreItems(appId, hiveName, key, items) {
      return req.put(routes.addListStoreItems(appId, hiveName, key), items);
    },
    removeHiveListStoreItemByValue: function removeHiveListStoreItemByValue(appId, hiveName, key, value) {
      return req.put(routes.removeListStoreItemByValue(appId, hiveName, key), {
        value: value
      });
    },
    updateHiveListStoreItemByIndex: function updateHiveListStoreItemByIndex(appId, hiveName, key, index, value) {
      return req.put(routes.listStoreItemByIndex(appId, hiveName, key, index), {
        value: value
      });
    },
    //---- LIST Type -------------------------//
    //---- SET Type -------------------------//
    addHiveSetStoreItems: function addHiveSetStoreItems(appId, hiveName, key, items) {
      return req.put(routes.addSetStoreItems(appId, hiveName, key), items);
    },
    removeHiveSetStoreItemByValue: function removeHiveSetStoreItemByValue(appId, hiveName, key, value) {
      return req["delete"](routes.removeSetStoreItemByValue(appId, hiveName, key), [value]);
    } //---- SET Type -------------------------//
  };
};
exports["default"] = _default;