"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _routes = require("./utils/routes");
/* eslint-disable max-len */
var routes = (0, _routes.prepareRoutes)({
  dashboards: '/:appId/console/data-to-visualize/dashboards',
  dashboard: '/:appId/console/data-to-visualize/dashboards/:dashboardId',
  dashboardClone: '/:appId/console/data-to-visualize/dashboards/:dashboardId/clone',
  dashboardSettings: '/:appId/console/data-to-visualize/dashboards/:dashboardId/settings',
  dashlets: '/:appId/console/data-to-visualize/dashboards/:dashboardId/dashlets',
  createDashlets: '/:appId/console/data-to-visualize/dashboards/:dashboardId/dashlets/create',
  dashlet: '/:appId/console/data-to-visualize/dashboards/:dashboardId/dashlets/:dashletId',
  dashletComponents: '/:appId/console/data-to-visualize/dashboards/:dashboardId/dashlet-components',
  dashletComponentInstall: '/:appId/console/data-to-visualize/dashboards/:dashboardId/dashlet-components/install',
  dashletComponentCreate: '/:appId/console/data-to-visualize/dashboards/:dashboardId/dashlet-components/create',
  dashletComponentUpgrade: '/:appId/console/data-to-visualize/dashboards/:dashboardId/dashlet-components/upgrade',
  dashletComponent: '/:appId/console/data-to-visualize/dashboards/:dashboardId/dashlet-components/:componentId/',
  dashletComponentFiles: '/:appId/console/data-to-visualize/dashboards/:dashboardId/dashlet-components/:componentId/files',
  dashletComponentFile: '/:appId/console/data-to-visualize/dashboards/:dashboardId/dashlet-components/:componentId/files/:fileId',
  dashletComponentFilesDownloadLink: '/:appId/console/data-to-visualize/dashboards/:dashboardId/dashlet-components/:componentId/files/sign'
});
var _default = function _default(req) {
  return {
    getDashboards: function getDashboards(appId, query) {
      return req.get(routes.dashboards(appId)).query(query);
    },
    createDashboard: function createDashboard(appId, dashboard) {
      return req.post(routes.dashboards(appId), dashboard);
    },
    cloneDashboard: function cloneDashboard(appId, dashboardId) {
      return req.post(routes.dashboardClone(appId, dashboardId));
    },
    updateDashboard: function updateDashboard(appId, dashboardId, changes) {
      return req.put(routes.dashboard(appId, dashboardId), changes);
    },
    updateDashboards: function updateDashboards(appId, changes) {
      return req.put(routes.dashboards(appId), changes);
    },
    updateDashboardSettings: function updateDashboardSettings(appId, dashboardId, settings) {
      return req.put(routes.dashboardSettings(appId, dashboardId), settings);
    },
    deleteDashboard: function deleteDashboard(appId, name) {
      return req["delete"](routes.dashboard(appId, name));
    },
    addDashboardDashlet: function addDashboardDashlet(appId, dashboardId, dashletComponent) {
      return req.post(routes.dashlets(appId, dashboardId), dashletComponent);
    },
    createDashboardDashlets: function createDashboardDashlets(appId, dashboardId, dashlets) {
      return req.post(routes.createDashlets(appId, dashboardId), dashlets);
    },
    deleteDashboardDashlet: function deleteDashboardDashlet(appId, dashboardId, dashletId) {
      return req["delete"](routes.dashlet(appId, dashboardId, dashletId));
    },
    updateDashboardDashlet: function updateDashboardDashlet(appId, dashboardId, dashletId, changes) {
      return req.put(routes.dashlet(appId, dashboardId, dashletId), changes);
    },
    loadDashletComponents: function loadDashletComponents(appId, dashboardId) {
      return req.get(routes.dashletComponents(appId, dashboardId));
    },
    installDashletComponent: function installDashletComponent(appId, dashboardId, product) {
      return req.post(routes.dashletComponentInstall(appId, dashboardId), product);
    },
    upgradeDashletComponent: function upgradeDashletComponent(appId, dashboardId, product, versionId) {
      return req.post(routes.dashletComponentUpgrade(appId, dashboardId), {
        product: product,
        versionId: versionId
      });
    },
    createDashletComponent: function createDashletComponent(appId, dashboardId, dashlet) {
      return req.post(routes.dashletComponentCreate(appId, dashboardId), dashlet);
    },
    deleteDashletComponent: function deleteDashletComponent(appId, dashboardId, componentId) {
      return req["delete"](routes.dashletComponent(appId, dashboardId, componentId));
    },
    updateDashletComponent: function updateDashletComponent(appId, dashboardId, componentId, changes) {
      return req.put(routes.dashletComponent(appId, dashboardId, componentId), changes);
    },
    getDashletComponentFileDownloadLink: function getDashletComponentFileDownloadLink(appId, dashboardId, componentId, fileId) {
      return req.get(routes.dashletComponentFilesDownloadLink(appId, dashboardId, componentId)).query({
        fileId: fileId
      });
    },
    loadDashletComponentFilesList: function loadDashletComponentFilesList(appId, dashboardId, componentId) {
      return req.get(routes.dashletComponentFiles(appId, dashboardId, componentId));
    },
    loadDashletComponentFileContent: function loadDashletComponentFileContent(appId, dashboardId, componentId, fileName) {
      return req.get(routes.dashletComponentFile(appId, dashboardId, componentId, fileName));
    },
    uploadDashletComponentFiles: function uploadDashletComponentFiles(appId, dashboardId, componentId, files) {
      return req.post(routes.dashletComponentFiles(appId, dashboardId, componentId), files);
    },
    updateDashletComponentFiles: function updateDashletComponentFiles(appId, dashboardId, componentId, files) {
      return req.put(routes.dashletComponentFiles(appId, dashboardId, componentId), files);
    }
  };
};
exports["default"] = _default;