"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _urls = _interopRequireDefault(require("./urls"));
var _totalRows = _interopRequireDefault(require("./utils/total-rows"));
var _sqlBuilder = _interopRequireDefault(require("./utils/sql-builder"));
var _cacheTags = require("./utils/cache-tags");
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
var toServerFence = function toServerFence(_ref) {
  var objectId = _ref.objectId,
    name = _ref.name,
    qualCriteria = _ref.qualCriteria,
    type = _ref.type,
    nodes = _ref.nodes;
  return {
    name: name,
    objectId: objectId,
    qualCriteria: qualCriteria,
    fence: {
      nodes: nodes,
      type: type
    }
  };
};
var fromServerFence = function fromServerFence(_ref2) {
  var objectId = _ref2.objectId,
    name = _ref2.name,
    qualCriteria = _ref2.qualCriteria,
    fence = _ref2.fence,
    events = _ref2.events,
    isActive = _ref2.isActive;
  return _objectSpread({
    name: name,
    events: events,
    objectId: objectId,
    qualCriteria: qualCriteria,
    isActive: isActive
  }, fence);
};
var categoriesUrl = function categoriesUrl(appId) {
  return _urls["default"].geo(appId) + '/categories';
};
var pointsUrl = function pointsUrl(appId) {
  return _urls["default"].geo(appId) + '/points';
};
var rectUrl = function rectUrl(appId) {
  return _urls["default"].geo(appId) + '/rect';
};
var categoryPointsUrl = function categoryPointsUrl(appId, category) {
  return "".concat(_urls["default"].geo(appId), "/").concat(category, "/points");
};
var fenceUrl = function fenceUrl(appId, fenceId) {
  return _urls["default"].geo(appId) + '/fence' + (fenceId ? "/".concat(fenceId) : '');
};
var _default = function _default(req) {
  var getCategories = function getCategories(appId) {
    return req.get(categoriesUrl(appId));
  };
  var addCategory = function addCategory(appId, name) {
    return req.post(categoriesUrl(appId) + '/' + name, {
      name: name
    }).cacheTags((0, _cacheTags.GEO_CATEGORY)(appId, name));
  };
  var deleteCategory = function deleteCategory(appId, name) {
    return req["delete"](categoriesUrl(appId) + '/' + name).cacheTags((0, _cacheTags.GEO_CATEGORY)(appId, name));
  };
  var renameCategory = function renameCategory(appId, category, name) {
    var objectId = category.objectId;
    return req.put(categoriesUrl(appId) + '/' + category.name, {
      name: name,
      objectId: objectId
    });
  };
  var calculateDegreesPerPixel = function calculateDegreesPerPixel(bounds, zoomLevel, width) {
    var lonDistance = (bounds.east - bounds.west) * Math.pow(2, zoomLevel);
    var degree = lonDistance * Math.pow(2, -zoomLevel);
    if (degree < 0) {
      degree += 360;
    }
    return degree / width;
  };
  var getFences = function getFences(appId) {
    return req.get(_urls["default"].geo(appId) + '/fences').then(function (result) {
      return result.map(fromServerFence);
    });
  };
  var saveFence = function saveFence(appId, fence) {
    var body = toServerFence(fence); //TODO: create server ticket

    if (fence.objectId) {
      return req.put(_urls["default"].geo(appId) + '/fence/' + fence.objectId, body).then(fromServerFence);
    }
    return req.post(fenceUrl(appId), body).then(fromServerFence);
  };
  var saveFenceAction = function saveFenceAction(appId, fenceId, event, action) {
    return req.post("".concat(fenceUrl(appId, fenceId), "/").concat(event.toLowerCase()), action || {});
  };
  var executeFenceEvent = function executeFenceEvent(appId, fenceId, event) {
    return req.post("".concat(fenceUrl(appId, fenceId), "/run/").concat(event.toLowerCase()));
  };
  var deleteFence = function deleteFence(appId, fenceId) {
    return req["delete"](fenceUrl(appId, fenceId));
  };
  var activateFence = function activateFence(appId, fenceId) {
    var applyOnStay = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
    return req.put("".concat(fenceUrl(appId, fenceId), "/activate"), {
      applyOnStay: applyOnStay
    });
  };
  var deactivateFence = function deactivateFence(appId, fenceId) {
    return req.put("".concat(fenceUrl(appId, fenceId), "/deactivate"));
  };
  var getPoints = function getPoints(appId, category) {
    var params = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    var _params$offset = params.offset,
      offset = _params$offset === void 0 ? 0 : _params$offset,
      _params$pageSize = params.pageSize,
      pageSize = _params$pageSize === void 0 ? 15 : _params$pageSize,
      relationsParams = params.relationsParams;
    var pageParams = {
      offset: offset,
      pagesize: pageSize
    };
    if (relationsParams) {
      return loadPointsAsRelations(appId, params, pageParams);
    }
    return (0, _totalRows["default"])(req).getWithData(loadPoints(appId, category, params, pageParams));
  };
  var loadPoints = function loadPoints(appId, category, params, pageParams) {
    var where = params.where,
      _params$includemetada = params.includemetadata,
      includemetadata = _params$includemetada === void 0 ? true : _params$includemetada,
      filterString = params.filterString;
    var mapBounds = params.mapBounds,
      mapDriven = params.mapDriven,
      mapZoom = params.mapZoom,
      mapWidth = params.mapWidth,
      clustering = params.clustering;
    var radiusDriven = params.radiusDriven,
      radiusCenter = params.radiusCenter,
      radius = params.radius,
      radiusUnits = params.radiusUnits;
    var queryParams = _objectSpread(_objectSpread({}, pageParams), {}, {
      includemetadata: includemetadata,
      categories: category,
      where: _sqlBuilder["default"].and(where, filterString)
    });
    if (mapDriven) {
      if (radiusDriven) {
        queryParams.lat = radiusCenter.lat;
        queryParams.lon = radiusCenter.lng;
        queryParams.r = radius;
        queryParams.units = radiusUnits.toUpperCase();
      } else {
        queryParams.nwlat = mapBounds.north;
        queryParams.nwlon = mapBounds.west;
        queryParams.selat = mapBounds.south;
        queryParams.selon = mapBounds.east;
      }
      if (clustering) {
        queryParams.dpp = calculateDegreesPerPixel(mapBounds, mapZoom, mapWidth);
      }
    }
    var nonRadiusMapDrivenSearch = mapDriven && !radiusDriven;
    var url = nonRadiusMapDrivenSearch ? rectUrl(appId) : pointsUrl(appId);
    return req.get(url).query(queryParams).cacheTags((0, _cacheTags.GEO_CATEGORY)(appId, category));
  };
  var loadPointsAsRelations = function loadPointsAsRelations(appId, params, pageParams) {
    var where = params.where,
      filterString = params.filterString,
      relationsParams = params.relationsParams;
    var mapDriven = params.mapDriven,
      radiusDriven = params.radiusDriven,
      radiusCenter = params.radiusCenter,
      radius = params.radius,
      radiusUnits = params.radiusUnits;
    var tableName = relationsParams.tableName,
      objectId = relationsParams.objectId,
      name = relationsParams.name,
      related = relationsParams.related;
    var whereClauseParts = [where, filterString];
    if (mapDriven && radiusDriven) {
      var lat = radiusCenter.lat,
        lng = radiusCenter.lng;
      whereClauseParts.push(_sqlBuilder["default"].distance(lat, lng, radiusUnits, radius));
    }
    var queryParams = _objectSpread(_objectSpread({}, pageParams), {}, {
      where: _sqlBuilder["default"].and.apply(_sqlBuilder["default"], whereClauseParts),
      related: related
    });
    var dataReq = req.get("".concat(_urls["default"].dataRecord(appId, tableName, objectId), "/").concat(name)).query(queryParams);
    return (0, _totalRows["default"])(req).getWithData(dataReq).then(function (_ref3) {
      var totalRows = _ref3.totalRows,
        data = _ref3.data;
      var objectIds = [];
      data.forEach(function (point) {
        if (!objectIds.includes(point.objectId)) {
          objectIds.push(point.objectId);
        }
      });
      return loadPointsByIds(appId, objectIds, params.includemetadata).then(function (points) {
        var pointsMap = {};
        points.forEach(function (point) {
          return pointsMap[point.objectId] = point;
        });
        var data = objectIds.map(function (pointId) {
          return pointsMap[pointId];
        });
        return {
          totalRows: totalRows,
          data: data
        };
      });
    });
  };
  var loadPointsByIds = function loadPointsByIds(appId) {
    var objectIds = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
    var includemetadata = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
    var queryParams = {
      pagesize: objectIds.length,
      includemetadata: includemetadata,
      where: _sqlBuilder["default"]["in"]('objectId', objectIds)
    };
    return req.get(pointsUrl(appId)).query(queryParams).cacheTags((0, _cacheTags.GEO_CATEGORY)(appId));
  };
  var getFencePoints = function getFencePoints(appId, fenceId) {
    return req.get("".concat(fenceUrl(appId, fenceId), "/geopoints")).then(function (data) {
      return {
        data: data,
        totalPoints: data.length
      };
    });
  };
  var deletePoints = function deletePoints(appId, category, pointsIds) {
    return req["delete"](categoryPointsUrl(appId, category), pointsIds).cacheTags((0, _cacheTags.GEO_CATEGORY)(appId, category));
  };
  var addPoint = function addPoint(appId, lat, lon) {
    return req.put(pointsUrl(appId)).query({
      lat: lat,
      lon: lon
    });
  };
  var copyPoints = function copyPoints(appId, pointsIds, targetCategory) {
    return req.put(_urls["default"].geo(appId) + '/' + targetCategory, pointsIds).cacheTags((0, _cacheTags.GEO_CATEGORY)(appId, targetCategory));
  };
  var setPointMeta = function setPointMeta(appId, pointId, meta) {
    return req.put("".concat(_urls["default"].geo(appId), "/").concat(pointId, "/meta"), meta);
  };
  var addPointMetaRelations = function addPointMetaRelations(appId, pointId, meta) {
    return req.patch("".concat(_urls["default"].geo(appId), "/").concat(pointId, "/meta"), meta);
  };
  var removePointMetaRelations = function removePointMetaRelations(appId, pointId, meta) {
    return req["delete"]("".concat(_urls["default"].geo(appId), "/").concat(pointId, "/meta"), meta);
  };
  var reset = function reset(appId) {
    return req["delete"](_urls["default"].geo(appId)).cacheTags((0, _cacheTags.GEO_CATEGORY)(appId));
  };
  var sampleSetup = function sampleSetup(appId) {
    return req.post(_urls["default"].geo(appId) + '/samplesetup').cacheTags((0, _cacheTags.GEO_CATEGORY)(appId));
  };
  return {
    getCategories: getCategories,
    addCategory: addCategory,
    renameCategory: renameCategory,
    deleteCategory: deleteCategory,
    getPoints: getPoints,
    getFencePoints: getFencePoints,
    getFences: getFences,
    saveFence: saveFence,
    saveFenceAction: saveFenceAction,
    executeFenceEvent: executeFenceEvent,
    deleteFence: deleteFence,
    activateFence: activateFence,
    deactivateFence: deactivateFence,
    addPoint: addPoint,
    deletePoints: deletePoints,
    copyPoints: copyPoints,
    sampleSetup: sampleSetup,
    setPointMeta: setPointMeta,
    addPointMetaRelations: addPointMetaRelations,
    removePointMetaRelations: removePointMetaRelations,
    reset: reset
  };
};
exports["default"] = _default;