"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.viewRecordsReq = exports.viewRecordsGroupReq = exports.viewRecordsGroupCountReq = exports.viewRecordsCountReq = void 0;
var _cacheTags = require("./cache-tags");
var CommonRequestProperties = ['where', 'distinct', 'props', 'excludeProps', 'property', 'loadRelations', 'sortBy'];
var GroupRequestProperties = [].concat(CommonRequestProperties, ['groupDepth', 'relationsPageSize', 'groupPath', 'groupBy']);
var GroupCountRequestProperties = ['where', 'distinct'];
var assignPropertiesIfDefined = function assignPropertiesIfDefined(target, source, properties) {
  return properties.reduce(function (acc, property) {
    if (source.hasOwnProperty(property) && source[property]) {
      acc[property] = source[property];
      return acc;
    }
    return acc;
  }, target);
};
var viewRecordsReq = function viewRecordsReq(req, url, view, query, resetCache) {
  var _query$pageSize = query.pageSize,
    pageSize = _query$pageSize === void 0 ? 15 : _query$pageSize,
    _query$offset = query.offset,
    offset = _query$offset === void 0 ? 0 : _query$offset;
  var params = {
    offset: offset,
    pageSize: pageSize
  };
  assignPropertiesIfDefined(params, query, CommonRequestProperties);
  return req.post(url, params).cacheTags((0, _cacheTags.VIEW_DATA)(view.viewId)).resetCache(resetCache);
};
exports.viewRecordsReq = viewRecordsReq;
var viewRecordsCountReq = function viewRecordsCountReq(req, url, view, query, resetCache) {
  var _query$pageSize2 = query.pageSize,
    pageSize = _query$pageSize2 === void 0 ? 15 : _query$pageSize2,
    _query$offset2 = query.offset,
    offset = _query$offset2 === void 0 ? 0 : _query$offset2;
  var params = {
    offset: offset,
    pageSize: pageSize
  };
  assignPropertiesIfDefined(params, query, CommonRequestProperties);
  return req.post(url, params).cacheTags((0, _cacheTags.VIEW_DATA)(view.viewId)).resetCache(resetCache);
};
exports.viewRecordsCountReq = viewRecordsCountReq;
var viewRecordsGroupReq = function viewRecordsGroupReq(req, url, viewId, query) {
  var _query$offset3 = query.offset,
    offset = _query$offset3 === void 0 ? 0 : _query$offset3,
    _query$pageSize3 = query.pageSize,
    pageSize = _query$pageSize3 === void 0 ? 15 : _query$pageSize3,
    _query$groupPageSize = query.groupPageSize,
    groupPageSize = _query$groupPageSize === void 0 ? 5 : _query$groupPageSize,
    _query$recordsPageSiz = query.recordsPageSize,
    recordsPageSize = _query$recordsPageSiz === void 0 ? 5 : _query$recordsPageSiz;
  var params = {
    offset: offset,
    pageSize: pageSize,
    groupPageSize: groupPageSize,
    recordsPageSize: recordsPageSize
  };
  assignPropertiesIfDefined(params, query, GroupRequestProperties);
  return req.post(url, params).cacheTags((0, _cacheTags.VIEW_GROUP_DATA)(viewId));
};
exports.viewRecordsGroupReq = viewRecordsGroupReq;
var viewRecordsGroupCountReq = function viewRecordsGroupCountReq(req, url, query) {
  var groupPath = query.groupPath;
  var params = {
    groupPath: groupPath
  };
  assignPropertiesIfDefined(params, query, GroupCountRequestProperties);
  return req.post(url, params);
};
exports.viewRecordsGroupCountReq = viewRecordsGroupCountReq;